import { CommonModule } from '@angular/common';
import { HttpClient, HttpParams, HttpRequest, HttpClientModule } from '@angular/common/http';
import * as _ from 'lodash';
import { forOwn, isArray, mapValues, isBoolean, cloneDeep, omit } from 'lodash';
import { __spread, __awaiter, __generator, __extends } from 'tslib';
import { InjectionToken, Injectable, Inject, NgModule, Optional, SkipSelf, defineInjectable, inject } from '@angular/core';
import { JwtHelperService } from '@auth0/angular-jwt';
import { NgForage } from 'ngforage';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
var EnvironmentConfigService = new InjectionToken('EnvironmentConfigService');

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @enum {string} */
var HttpMethods = {
    GET: 'GET',
    POST: 'POST',
    PUT: 'PUT',
    PATCH: 'PUT',
    DELETE: 'DELETE',
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
var methodsWithBody = [HttpMethods.POST, HttpMethods.PUT, HttpMethods.PATCH];
/** @type {?} */
var defaultUploadingSections = ['media'];
var HttpService = /** @class */ (function () {
    function HttpService(http, config) {
        this.http = http;
        this.config = config;
        this.uploadingSections = this.config.uploadingSections || defaultUploadingSections;
    }
    /**
     * @return {?}
     */
    HttpService.prototype.getConfig = /**
     * @return {?}
     */
    function () {
        return this.config;
    };
    /**
     * @private
     * @param {?} urlParams
     * @param {?} method
     * @param {?} options
     * @return {?}
     */
    HttpService.prototype.handle = /**
     * @private
     * @param {?} urlParams
     * @param {?} method
     * @param {?} options
     * @return {?}
     */
    function (urlParams, method, options) {
        /** @type {?} */
        var isBodyMethod = (methodsWithBody.indexOf(method) !== -1);
        options = this.filterParams(urlParams, !isBodyMethod, options);
        if (!isBodyMethod) {
            options = {
                params: new HttpParams({
                    fromObject: options
                }),
                responseType: urlParams.responseType || 'json'
            };
        }
        /** @type {?} */
        var request = new HttpRequest(method, this.buildUrl(urlParams), options);
        // add header to prevent token checking for public requests (eg. login, reset password etc)
        if (urlParams.insecure === true) {
            request = request.clone({ setHeaders: { Insecure: '1' } });
            delete urlParams.insecure;
        }
        return this.http.request(request)
            .toPromise()
            .then((/**
         * @param {?} event
         * @return {?}
         */
        function (event) {
            return {
                result: true,
                data: (urlParams.rawResponse === true) ? event : event.body
            };
        }))
            .catch((/**
         * @param {?} error
         * @return {?}
         */
        function (error) {
            return {
                result: false,
                error: (urlParams.rawResponse === true) ? error : error.error
            };
        }));
    };
    /**
     * @param {?} urlParams
     * @param {?=} params
     * @return {?}
     */
    HttpService.prototype.get = /**
     * @param {?} urlParams
     * @param {?=} params
     * @return {?}
     */
    function (urlParams, params) {
        if (params === void 0) { params = {}; }
        return this.handle(urlParams, HttpMethods.GET, params);
    };
    /**
     * @param {?} urlParams
     * @param {?=} params
     * @return {?}
     */
    HttpService.prototype.search = /**
     * @param {?} urlParams
     * @param {?=} params
     * @return {?}
     */
    function (urlParams, params) {
        if (params === void 0) { params = {}; }
        return this.handle(urlParams, HttpMethods.GET, params);
    };
    /**
     * @param {?} urlParams
     * @param {?} data
     * @return {?}
     */
    HttpService.prototype.save = /**
     * @param {?} urlParams
     * @param {?} data
     * @return {?}
     */
    function (urlParams, data) {
        return this.handle(urlParams, HttpMethods.POST, data);
    };
    /**
     * @param {?} urlParams
     * @param {?} data
     * @return {?}
     */
    HttpService.prototype.update = /**
     * @param {?} urlParams
     * @param {?} data
     * @return {?}
     */
    function (urlParams, data) {
        return this.handle(urlParams, HttpMethods.PUT, data);
    };
    /**
     * @param {?} urlParams
     * @param {?=} params
     * @return {?}
     */
    HttpService.prototype.delete = /**
     * @param {?} urlParams
     * @param {?=} params
     * @return {?}
     */
    function (urlParams, params) {
        if (params === void 0) { params = {}; }
        return this.handle(urlParams, HttpMethods.DELETE, params);
    };
    /**
     * Transform keys to `key[]` for array type vales
     * and remove params with empty values
     */
    /**
     * Transform keys to `key[]` for array type vales
     * and remove params with empty values
     * @private
     * @param {?} urlParams
     * @param {?} convertToArray
     * @param {?} options
     * @return {?}
     */
    HttpService.prototype.filterParams = /**
     * Transform keys to `key[]` for array type vales
     * and remove params with empty values
     * @private
     * @param {?} urlParams
     * @param {?} convertToArray
     * @param {?} options
     * @return {?}
     */
    function (urlParams, convertToArray, options) {
        /** @type {?} */
        var params = {};
        // formdata should stay as is
        if (options instanceof FormData) {
            params = options;
        }
        else {
            forOwn(options, (/**
             * @param {?} value
             * @param {?} key
             * @return {?}
             */
            function (value, key) {
                if (convertToArray && isArray(value) && key.indexOf('[]') === -1) {
                    key += '[]';
                }
                if (value !== null && value !== undefined) {
                    params[key] = value;
                }
            }));
            // convert boolean values to numeric except media content
            if (this.uploadingSections.indexOf(urlParams.section) === -1) {
                params = mapValues(params, (/**
                 * @param {?} value
                 * @return {?}
                 */
                function (value) { return isBoolean(value) ? +value : value; }));
            }
        }
        return params;
    };
    /**
     * Make url like `/section/id/cmd/secondId`
     */
    /**
     * Make url like `/section/id/cmd/secondId`
     * @private
     * @param {?} urlParams
     * @return {?}
     */
    HttpService.prototype.buildUrl = /**
     * Make url like `/section/id/cmd/secondId`
     * @private
     * @param {?} urlParams
     * @return {?}
     */
    function (urlParams) {
        /** @type {?} */
        var url = [this.config.url + "/" + urlParams.section];
        if (urlParams.id !== undefined) {
            url.push("" + urlParams.id);
        }
        if (urlParams.cmd) {
            url.push("" + urlParams.cmd);
        }
        if (urlParams.secondId) {
            url.push("" + urlParams.secondId);
        }
        return url.join('/');
    };
    HttpService.decorators = [
        { type: Injectable, args: [{
                    providedIn: 'root'
                },] }
    ];
    /** @nocollapse */
    HttpService.ctorParameters = function () { return [
        { type: HttpClient },
        { type: undefined, decorators: [{ type: Inject, args: [EnvironmentConfigService,] }] }
    ]; };
    /** @nocollapse */ HttpService.ngInjectableDef = defineInjectable({ factory: function HttpService_Factory() { return new HttpService(inject(HttpClient), inject(EnvironmentConfigService)); }, token: HttpService, providedIn: "root" });
    return HttpService;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @enum {number} */
var RequestTypes = {
    GET: 0,
    SEARCH: 1,
    ADD: 2,
    UPDATE: 3,
    DELETE: 4,
    RESTORE: 5,
};
RequestTypes[RequestTypes.GET] = 'GET';
RequestTypes[RequestTypes.SEARCH] = 'SEARCH';
RequestTypes[RequestTypes.ADD] = 'ADD';
RequestTypes[RequestTypes.UPDATE] = 'UPDATE';
RequestTypes[RequestTypes.DELETE] = 'DELETE';
RequestTypes[RequestTypes.RESTORE] = 'RESTORE';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @abstract
 * @template T
 */
var  /**
 * @abstract
 * @template T
 */
GetRequest = /** @class */ (function () {
    function GetRequest(service, queryParams) {
        this.service = service;
        this.queryParams = queryParams;
    }
    /**
     * @template THIS
     * @this {THIS}
     * @param {?} urlParams
     * @return {THIS}
     */
    GetRequest.prototype.url = /**
     * @template THIS
     * @this {THIS}
     * @param {?} urlParams
     * @return {THIS}
     */
    function (urlParams) {
        (/** @type {?} */ (this)).urlParams = urlParams;
        return (/** @type {?} */ (this));
    };
    /**
     * Implementation of the adding `with_trashed` into request
     *
     * @param {boolean} value
     */
    /**
     * Implementation of the adding `with_trashed` into request
     *
     * @template THIS
     * @this {THIS}
     * @param {?=} value
     * @return {THIS}
     */
    GetRequest.prototype.withTrashed = /**
     * Implementation of the adding `with_trashed` into request
     *
     * @template THIS
     * @this {THIS}
     * @param {?=} value
     * @return {THIS}
     */
    function (value) {
        if (value === void 0) { value = true; }
        (/** @type {?} */ (this)).queryParams.with_trashed = value;
        return (/** @type {?} */ (this));
    };
    return GetRequest;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @template T
 */
var  /**
 * @template T
 */
ApiGetRequest = /** @class */ (function (_super) {
    __extends(ApiGetRequest, _super);
    function ApiGetRequest(service, queryParams) {
        var _this = _super.call(this, service, queryParams) || this;
        _this.service = service;
        _this.queryParams = queryParams;
        return _this;
    }
    /**
     * @template THIS
     * @this {THIS}
     * @param {?} id
     * @return {THIS}
     */
    ApiGetRequest.prototype.id = /**
     * @template THIS
     * @this {THIS}
     * @param {?} id
     * @return {THIS}
     */
    function (id) {
        (/** @type {?} */ (this)).queryParams.id = id;
        return (/** @type {?} */ (this));
    };
    /**
     * @template THIS
     * @this {THIS}
     * @param {?} value
     * @return {THIS}
     */
    ApiGetRequest.prototype.with = /**
     * @template THIS
     * @this {THIS}
     * @param {?} value
     * @return {THIS}
     */
    function (value) {
        (/** @type {?} */ (this)).queryParams.with = value;
        return (/** @type {?} */ (this));
    };
    /**
     * @return {?}
     */
    ApiGetRequest.prototype.execute = /**
     * @return {?}
     */
    function () {
        /** @type {?} */
        var params = cloneDeep(this.queryParams);
        delete params.id;
        return this.service.get(this.queryParams.id, params || {});
    };
    return ApiGetRequest;
}(GetRequest));

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @template T
 */
var  /**
 * @template T
 */
ApiSearchRequest = /** @class */ (function (_super) {
    __extends(ApiSearchRequest, _super);
    function ApiSearchRequest(service, queryParams) {
        var _this = _super.call(this, service, queryParams) || this;
        _this.service = service;
        _this.queryParams = queryParams;
        return _this;
    }
    // TODO: try to use decorator to change url (as parameter of function) + use declare in service
    // TODO: try to use decorator to change url (as parameter of function) + use declare in service
    /**
     * @template THIS
     * @this {THIS}
     * @param {?} value
     * @return {THIS}
     */
    ApiSearchRequest.prototype.query = 
    // TODO: try to use decorator to change url (as parameter of function) + use declare in service
    /**
     * @template THIS
     * @this {THIS}
     * @param {?} value
     * @return {THIS}
     */
    function (value) {
        (/** @type {?} */ (this)).queryParams.query = value;
        return (/** @type {?} */ (this));
    };
    /**
     * @template THIS
     * @this {THIS}
     * @param {?} value
     * @return {THIS}
     */
    ApiSearchRequest.prototype.page = /**
     * @template THIS
     * @this {THIS}
     * @param {?} value
     * @return {THIS}
     */
    function (value) {
        (/** @type {?} */ (this)).queryParams.page = value;
        return (/** @type {?} */ (this));
    };
    /**
     * @template THIS
     * @this {THIS}
     * @param {?} value
     * @return {THIS}
     */
    ApiSearchRequest.prototype.perPage = /**
     * @template THIS
     * @this {THIS}
     * @param {?} value
     * @return {THIS}
     */
    function (value) {
        (/** @type {?} */ (this)).queryParams.per_page = value;
        return (/** @type {?} */ (this));
    };
    /**
     * @template THIS
     * @this {THIS}
     * @param {?} field
     * @param {?} value
     * @return {THIS}
     */
    ApiSearchRequest.prototype.filterBy = /**
     * @template THIS
     * @this {THIS}
     * @param {?} field
     * @param {?} value
     * @return {THIS}
     */
    function (field, value) {
        (/** @type {?} */ (this)).queryParams[field] = value;
        return (/** @type {?} */ (this));
    };
    /**
     * @template THIS
     * @this {THIS}
     * @param {?} field
     * @param {?=} isDescending
     * @return {THIS}
     */
    ApiSearchRequest.prototype.orderBy = /**
     * @template THIS
     * @this {THIS}
     * @param {?} field
     * @param {?=} isDescending
     * @return {THIS}
     */
    function (field, isDescending) {
        if (isDescending === void 0) { isDescending = false; }
        (/** @type {?} */ (this)).queryParams.order_by = field;
        (/** @type {?} */ (this)).queryParams.desc = isDescending;
        return (/** @type {?} */ (this));
    };
    /**
     * @template THIS
     * @this {THIS}
     * @param {?=} value
     * @return {THIS}
     */
    ApiSearchRequest.prototype.all = /**
     * @template THIS
     * @this {THIS}
     * @param {?=} value
     * @return {THIS}
     */
    function (value) {
        if (value === void 0) { value = true; }
        (/** @type {?} */ (this)).queryParams.all = value;
        return (/** @type {?} */ (this));
    };
    /**
     * @template THIS
     * @this {THIS}
     * @param {?} value
     * @return {THIS}
     */
    ApiSearchRequest.prototype.with = /**
     * @template THIS
     * @this {THIS}
     * @param {?} value
     * @return {THIS}
     */
    function (value) {
        (/** @type {?} */ (this)).queryParams.with = value;
        return (/** @type {?} */ (this));
    };
    /**
     * @return {?}
     */
    ApiSearchRequest.prototype.execute = /**
     * @return {?}
     */
    function () {
        return this.service.search(this.queryParams, this.urlParams);
    };
    return ApiSearchRequest;
}(GetRequest));

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @abstract
 * @template T
 */
var  /**
 * @abstract
 * @template T
 */
PostRequest = /** @class */ (function () {
    function PostRequest(service, entity) {
        this.service = service;
        this.entity = entity;
    }
    /**
     * @template THIS
     * @this {THIS}
     * @param {?} urlParams
     * @return {THIS}
     */
    PostRequest.prototype.url = /**
     * @template THIS
     * @this {THIS}
     * @param {?} urlParams
     * @return {THIS}
     */
    function (urlParams) {
        (/** @type {?} */ (this)).urlParams = urlParams;
        return (/** @type {?} */ (this));
    };
    /**
     * @template THIS
     * @this {THIS}
     * @param {?} data
     * @return {THIS}
     */
    PostRequest.prototype.data = /**
     * @template THIS
     * @this {THIS}
     * @param {?} data
     * @return {THIS}
     */
    function (data) {
        (/** @type {?} */ (this)).entity = data;
        return (/** @type {?} */ (this));
    };
    // filter(filter: ((data: any) => T) | string[]): ApiBodyRequest<T> {
    // filter(filter: ((data: any) => T) | string[]): ApiBodyRequest<T> {
    /**
     * @template THIS
     * @this {THIS}
     * @param {?} filter
     * @return {THIS}
     */
    PostRequest.prototype.filter = 
    // filter(filter: ((data: any) => T) | string[]): ApiBodyRequest<T> {
    /**
     * @template THIS
     * @this {THIS}
     * @param {?} filter
     * @return {THIS}
     */
    function (filter) {
        if (typeof filter === 'function') {
            (/** @type {?} */ (this)).entity = filter((/** @type {?} */ (this)).entity);
        }
        else {
            (/** @type {?} */ (this)).entity = (/** @type {?} */ (omit((/** @type {?} */ (this)).entity, filter)));
        }
        return (/** @type {?} */ (this));
    };
    return PostRequest;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @template T
 */
var  /**
 * @template T
 */
ApiAddRequest = /** @class */ (function (_super) {
    __extends(ApiAddRequest, _super);
    function ApiAddRequest() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    /**
     * @return {?}
     */
    ApiAddRequest.prototype.execute = /**
     * @return {?}
     */
    function () {
        return this.service.add(this.entity, this.urlParams);
    };
    return ApiAddRequest;
}(PostRequest));

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @template T
 */
var  /**
 * @template T
 */
ApiUpdateRequest = /** @class */ (function (_super) {
    __extends(ApiUpdateRequest, _super);
    function ApiUpdateRequest() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    /**
     * @return {?}
     */
    ApiUpdateRequest.prototype.execute = /**
     * @return {?}
     */
    function () {
        return this.service.update(this.entity, this.urlParams);
    };
    return ApiUpdateRequest;
}(PostRequest));

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @template T
 */
var ApiService = /** @class */ (function () {
    function ApiService(httpService) {
        this.httpService = httpService;
        this.section = '';
        this.omittedFields = [];
        this.isInsecure = false;
        this.useAutoConstructor = false;
        this.getSection();
    }
    /**
     * @private
     * @return {?}
     */
    ApiService.prototype.getSection = /**
     * @private
     * @return {?}
     */
    function () {
        this.section = this.section || this.constructor.name
            .toLowerCase()
            .replace('service', '');
    };
    /**
     * Commmon get entity by id request
     */
    /**
     * Commmon get entity by id request
     * @param {?} id
     * @param {?=} params
     * @param {?=} urlParams
     * @return {?}
     */
    ApiService.prototype.get = /**
     * Commmon get entity by id request
     * @param {?} id
     * @param {?=} params
     * @param {?=} urlParams
     * @return {?}
     */
    function (id, params, urlParams) {
        /** @type {?} */
        var url = urlParams || {
            section: this.section,
            id: id,
            insecure: this.isInsecure
        };
        return this.httpService.get(url, params);
    };
    /**
     * Common add entity request
     */
    /**
     * Common add entity request
     * @param {?} data
     * @param {?=} urlParams
     * @return {?}
     */
    ApiService.prototype.add = /**
     * Common add entity request
     * @param {?} data
     * @param {?=} urlParams
     * @return {?}
     */
    function (data, urlParams) {
        /** @type {?} */
        var url = urlParams || {
            section: this.section,
            insecure: this.isInsecure
        };
        return this.httpService.save(url, this.omitFields(data));
    };
    /**
     * Common update entity request
     * Note: `id` property is required
     */
    /**
     * Common update entity request
     * Note: `id` property is required
     * @param {?} data
     * @param {?=} urlParams
     * @return {?}
     */
    ApiService.prototype.update = /**
     * Common update entity request
     * Note: `id` property is required
     * @param {?} data
     * @param {?=} urlParams
     * @return {?}
     */
    function (data, urlParams) {
        if (data.id === undefined || data.id === null) {
            throw new Error('`id` property is required for update request');
        }
        /** @type {?} */
        var url = urlParams || {
            section: this.section,
            id: data.id,
            insecure: this.isInsecure
        };
        /** @type {?} */
        var dataWithoutId = cloneDeep(data);
        delete dataWithoutId.id;
        return this.httpService.update(url, dataWithoutId);
    };
    /**
     * Common delete entity by id request
     */
    /**
     * Common delete entity by id request
     * @param {?} id
     * @param {?=} urlParams
     * @return {?}
     */
    ApiService.prototype.delete = /**
     * Common delete entity by id request
     * @param {?} id
     * @param {?=} urlParams
     * @return {?}
     */
    function (id, urlParams) {
        /** @type {?} */
        var url = urlParams || {
            section: this.section,
            id: id,
            insecure: this.isInsecure
        };
        return this.httpService.delete(url);
    };
    /**
     * Delete list of entities
     * Note: works only if backend supports this method
     */
    /**
     * Delete list of entities
     * Note: works only if backend supports this method
     * @param {?} ids
     * @param {?=} urlParams
     * @return {?}
     */
    ApiService.prototype.deleteGroup = /**
     * Delete list of entities
     * Note: works only if backend supports this method
     * @param {?} ids
     * @param {?=} urlParams
     * @return {?}
     */
    function (ids, urlParams) {
        /** @type {?} */
        var url = urlParams || {
            section: this.section,
            insecure: this.isInsecure
        };
        return this.httpService
            .delete(url, {
            'ids[]': ids
        });
    };
    /**
     * Common restore entity by id request
     */
    /**
     * Common restore entity by id request
     * @param {?} id
     * @param {?=} urlParams
     * @return {?}
     */
    ApiService.prototype.restore = /**
     * Common restore entity by id request
     * @param {?} id
     * @param {?=} urlParams
     * @return {?}
     */
    function (id, urlParams) {
        /** @type {?} */
        var url = urlParams || {
            section: this.section,
            id: id,
            cmd: 'restore',
            insecure: this.isInsecure
        };
        return this.httpService.save(url, {});
    };
    /**
     * Restore list of entities
     * Note: works only if backend supports this method)
     */
    /**
     * Restore list of entities
     * Note: works only if backend supports this method)
     * @param {?} ids
     * @param {?=} urlParams
     * @return {?}
     */
    ApiService.prototype.restoreGroup = /**
     * Restore list of entities
     * Note: works only if backend supports this method)
     * @param {?} ids
     * @param {?=} urlParams
     * @return {?}
     */
    function (ids, urlParams) {
        /** @type {?} */
        var url = urlParams || {
            section: this.section,
            id: 'restore',
            insecure: this.isInsecure
        };
        return this.httpService
            .save(url, {
            'ids[]': ids
        });
    };
    /**
     * Common search request
     */
    /**
     * Common search request
     * @param {?} searchParams
     * @param {?=} urlParams
     * @return {?}
     */
    ApiService.prototype.search = /**
     * Common search request
     * @param {?} searchParams
     * @param {?=} urlParams
     * @return {?}
     */
    function (searchParams, urlParams) {
        var _this = this;
        /** @type {?} */
        var url = urlParams || {
            section: this.section,
            insecure: this.isInsecure
        };
        return this.httpService
            .search(url, searchParams)
            .then((/**
         * @param {?} response
         * @return {?}
         */
        function (response) {
            /** @type {?} */
            var adapivePagination = _this.httpService.getConfig().adaptivePagination || false;
            if (adapivePagination && searchParams && searchParams.all) {
                // FIXME: temporary solution until laravel backend will be updated to the new version
                response.data = {
                    current_page: 1,
                    data: response.data,
                    first_page_url: '',
                    from: 1,
                    last_page: 1,
                    last_page_url: '',
                    next_page_url: '',
                    path: '',
                    per_page: response.data.length,
                    prev_page_url: '',
                    to: response.data.length,
                    total: response.data.length
                };
            }
            return response;
        }));
    };
    /**
     * @param {?} method
     * @param {?=} params
     * @return {?}
     */
    ApiService.prototype.request = /**
     * @param {?} method
     * @param {?=} params
     * @return {?}
     */
    function (method, params) {
        if (params === void 0) { params = {}; }
        /** @type {?} */
        var request;
        switch (method) {
            case RequestTypes.SEARCH: {
                request = new ApiSearchRequest(this, params);
                break;
            }
            case RequestTypes.GET: {
                request = new ApiGetRequest(this, params);
                break;
            }
            case RequestTypes.ADD: {
                request = new ApiAddRequest(this, params);
                break;
            }
            case RequestTypes.UPDATE: {
                request = new ApiUpdateRequest(this, params);
                break;
            }
        }
        return request;
    };
    /**
     * @protected
     * @template Y
     * @param {?} data
     * @return {?}
     */
    ApiService.prototype.omitFields = /**
     * @protected
     * @template Y
     * @param {?} data
     * @return {?}
     */
    function (data) {
        return omit.apply(_, __spread([data], this.omittedFields));
    };
    ApiService.decorators = [
        { type: Injectable, args: [{
                    providedIn: 'root'
                },] }
    ];
    /** @nocollapse */
    ApiService.ctorParameters = function () { return [
        { type: HttpService }
    ]; };
    /** @nocollapse */ ApiService.ngInjectableDef = defineInjectable({ factory: function ApiService_Factory() { return new ApiService(inject(HttpService)); }, token: ApiService, providedIn: "root" });
    return ApiService;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
var AuthService = /** @class */ (function () {
    function AuthService(httpService, storageService) {
        this.httpService = httpService;
        this.storageService = storageService;
        this.jwtHelper = new JwtHelperService();
        this.user = null;
    }
    /**
     * @return {?}
     */
    AuthService.prototype.getToken = /**
     * @return {?}
     */
    function () {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.storageService.getItem('jwt')];
                    case 1: return [2 /*return*/, _a.sent()];
                }
            });
        });
    };
    /**
     * @param {?} token
     * @return {?}
     */
    AuthService.prototype.setToken = /**
     * @param {?} token
     * @return {?}
     */
    function (token) {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.storageService.setItem('jwt', token)];
                    case 1: return [2 /*return*/, _a.sent()];
                }
            });
        });
    };
    /**
     * Set current logged user
     */
    /**
     * Set current logged user
     * @param {?} user
     * @return {?}
     */
    AuthService.prototype.setUser = /**
     * Set current logged user
     * @param {?} user
     * @return {?}
     */
    function (user) {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.storageService.setItem('user', user)];
                    case 1:
                        _a.sent();
                        return [2 /*return*/];
                }
            });
        });
    };
    /**
     * @return {?}
     */
    AuthService.prototype.getUser = /**
     * @return {?}
     */
    function () {
        return __awaiter(this, void 0, void 0, function () {
            var user;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        if (!!this.user) return [3 /*break*/, 2];
                        return [4 /*yield*/, this.storageService.getItem('user')];
                    case 1:
                        user = _a.sent();
                        this.user = user;
                        return [2 /*return*/, user];
                    case 2: return [2 /*return*/, this.user];
                }
            });
        });
    };
    /**
     * Check if current user is authenticated
     */
    /**
     * Check if current user is authenticated
     * @return {?}
     */
    AuthService.prototype.isAuthenticated = /**
     * Check if current user is authenticated
     * @return {?}
     */
    function () {
        return __awaiter(this, void 0, void 0, function () {
            var token;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.getToken()];
                    case 1:
                        token = _a.sent();
                        return [2 /*return*/, token !== null && !this.jwtHelper.isTokenExpired(token)];
                }
            });
        });
    };
    /**
     * Attempt to refresh token
     */
    /**
     * Attempt to refresh token
     * @return {?}
     */
    AuthService.prototype.refreshToken = /**
     * Attempt to refresh token
     * @return {?}
     */
    function () {
        return __awaiter(this, void 0, void 0, function () {
            var refreshUrl;
            var _this = this;
            return __generator(this, function (_a) {
                refreshUrl = this.httpService.getConfig().tokenRefreshUrl;
                return [2 /*return*/, this.httpService
                        .search(refreshUrl || {
                        section: 'auth',
                        cmd: 'refresh',
                        rawResponse: true
                    })
                        .then((/**
                     * @param {?} response
                     * @return {?}
                     */
                    function (response) { return __awaiter(_this, void 0, void 0, function () {
                        var newToken, claims;
                        return __generator(this, function (_a) {
                            switch (_a.label) {
                                case 0:
                                    if (!response.result) return [3 /*break*/, 3];
                                    newToken = response.data.headers.get('authorization').split(' ')[1];
                                    claims = this.jwtHelper.decodeToken(newToken);
                                    return [4 /*yield*/, this.setUser(claims.user)];
                                case 1:
                                    _a.sent();
                                    return [4 /*yield*/, this.setToken(newToken)];
                                case 2:
                                    _a.sent();
                                    return [2 /*return*/, newToken];
                                case 3: return [2 /*return*/, ''];
                            }
                        });
                    }); }))];
            });
        });
    };
    /**
     * Clear all session variables
     */
    /**
     * Clear all session variables
     * @return {?}
     */
    AuthService.prototype.logout = /**
     * Clear all session variables
     * @return {?}
     */
    function () {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        this.user = null;
                        return [4 /*yield*/, this.storageService.removeItem('jwt')];
                    case 1:
                        _a.sent();
                        return [4 /*yield*/, this.storageService.removeItem('user')];
                    case 2:
                        _a.sent();
                        return [2 /*return*/];
                }
            });
        });
    };
    AuthService.decorators = [
        { type: Injectable }
    ];
    /** @nocollapse */
    AuthService.ctorParameters = function () { return [
        { type: HttpService },
        { type: NgForage }
    ]; };
    return AuthService;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
// export * from './ jlib/interceptors/api-auth.interceptor';
// export * from './lib/interceptors/api-jwt.interceptor';
var ApiLibModule = /** @class */ (function () {
    function ApiLibModule(parentModule) {
        if (parentModule) {
            throw new Error('ApiModule is already loaded. Import it in the AppModule only');
        }
    }
    /**
     * @param {?} config
     * @return {?}
     */
    ApiLibModule.forRoot = /**
     * @param {?} config
     * @return {?}
     */
    function (config) {
        return {
            ngModule: ApiLibModule,
            providers: [
                { provide: EnvironmentConfigService, useValue: config },
                HttpService,
                ApiService
                // { provide: HttpService, useClass: 'ApiHttpService' },
                // { provide: AuthService, useClass: 'ApiAuthService' },
            ]
        };
    };
    ApiLibModule.decorators = [
        { type: NgModule, args: [{
                    declarations: [],
                    imports: [
                        CommonModule,
                        HttpClientModule
                    ],
                    exports: [],
                    providers: [
                        HttpService,
                    ]
                },] }
    ];
    /** @nocollapse */
    ApiLibModule.ctorParameters = function () { return [
        { type: ApiLibModule, decorators: [{ type: Optional }, { type: SkipSelf }] }
    ]; };
    return ApiLibModule;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { ApiLibModule, HttpMethods, RequestTypes, ApiAddRequest, ApiGetRequest, ApiSearchRequest, ApiUpdateRequest, GetRequest, PostRequest, EnvironmentConfigService, HttpService, ApiService, AuthService };

//# sourceMappingURL=api-lib.js.map