import { HttpService } from './http.service';
import { RequestTypes } from '../enums/request-types.enum';
import { ApiEntity } from '../interfaces/api-entity';
import { GetParams } from '../interfaces/get-params';
import { UrlParams } from '../interfaces/url-params';
import { ApiResponse } from '../interfaces/api-response';
import { SearchParams } from '../interfaces/search-params';
import { ApiPagination } from '../interfaces/api-pagination';
import { ApiGetRequest } from '../requests/api-get.request';
import { ApiSearchRequest } from '../requests/api-search.request';
import { ApiAddRequest } from '../requests/api-add.request';
import { ApiUpdateRequest } from '../requests/api-update.request';
declare type Omit<T, K extends keyof T> = Pick<T, Exclude<keyof T, K>>;
export declare class ApiService<T extends ApiEntity> {
    protected httpService: HttpService;
    protected section: string;
    protected omittedFields: any[];
    protected isInsecure: boolean;
    protected useAutoConstructor: boolean;
    constructor(httpService: HttpService);
    private getSection;
    /**
     * Commmon get entity by id request
     */
    get(id: number | string, params?: Omit<GetParams, 'id'>, urlParams?: UrlParams): Promise<ApiResponse<T>>;
    /**
     * Common add entity request
     */
    add(data: Partial<T>, urlParams?: UrlParams): Promise<ApiResponse<T>>;
    /**
     * Common update entity request
     * Note: `id` property is required
     */
    update(data: Partial<T>, urlParams?: UrlParams): Promise<ApiResponse<void>>;
    /**
     * Common delete entity by id request
     */
    delete(id: number, urlParams?: UrlParams): Promise<ApiResponse<void>>;
    /**
     * Delete list of entities
     * Note: works only if backend supports this method
     */
    deleteGroup(ids: number[], urlParams?: UrlParams): Promise<ApiResponse<void>>;
    /**
     * Common restore entity by id request
     */
    restore(id: number, urlParams?: UrlParams): Promise<ApiResponse<void>>;
    /**
     * Restore list of entities
     * Note: works only if backend supports this method)
     */
    restoreGroup(ids: number[], urlParams?: UrlParams): Promise<ApiResponse<void>>;
    /**
     * Common search request
     */
    search(searchParams: SearchParams, urlParams?: UrlParams): Promise<ApiResponse<ApiPagination<T[]>>>;
    /**
     * Get entity by id request builder
     */
    request(method: RequestTypes.GET, params?: GetParams): ApiGetRequest<T>;
    /**
     * Search request builder
     */
    request(method: RequestTypes.SEARCH, params?: SearchParams): ApiSearchRequest<T>;
    /**
     * Add entity request builder
     */
    request(method: RequestTypes.ADD, params?: Partial<ApiEntity>): ApiAddRequest<T>;
    /**
     * Update entity request builder
     */
    request(method: RequestTypes.UPDATE, params?: Partial<ApiEntity>): ApiUpdateRequest<T>;
    protected omitFields<Y extends Partial<ApiEntity>>(data: T | Y): any;
}
export {};
